use strict;

=pod

=head2 LogFile

=over 1

Class representing a log file.

The file is opened for appending.
The entry starts with a line containing a time stamp.

=back

=cut

package LogFile;

sub new
{
	my ( $type, $timestamp, $tempfile_dir, $debug_level ) = @_;
	my $self = {
		TIMESTAMP => $timestamp,
		DIRNAME =>   $tempfile_dir,
		DEBUG_LEVEL => $debug_level
	};
	my $this = bless $self, $type;
	$self->init();
	return $this;
}

sub init
{
	my $self = shift;
	my $dirpath = $self->{DIRNAME};
	my $filepath = $dirpath . $self->{TIMESTAMP} . '.log';

	if( ! (-d $dirpath ) )
	{
		mkdir $dirpath
			or die "Could not write log file directory: $dirpath: $!";
	}
	my $file;
	open $file, ">>$filepath"
		or die "Could not write log file: $filepath: $!";
	$self->{FILE} = $file;
}

sub note
{
	my $self = shift;
	my $msg = shift;
	if( exists $self->{FILE} )
	{
		my $file = $self->{FILE};
		print $file "** $msg\n";
		(grep /status/, $self->{DEBUG_LEVEL}) and print "$msg\n";
	}
}

1;
